import { Injectable } from '@nestjs/common';
import * as ejs from 'ejs';
import * as sanitizeHtml from 'sanitize-html';
import { MailerService } from '../mailer/mailer.service';
import { ContactMessage } from './schemas/contact-message.schema';

@Injectable()
export class ContactService {
  constructor(private readonly mailerService: MailerService) {}

  public async sendMessage(contactMessage: ContactMessage): Promise<unknown> {
    const config = this.mailerService.config;
    const ejsPath = this.mailerService.getTemplateLocation(config.templates.contactMessage.ejs);
    const jsonConfig = this.mailerService.loadJsonConfig(config.templates.contactMessage.json);

    const html = await ejs.renderFile(ejsPath, {
      config,
      name: sanitizeHtml(contactMessage.name),
      email: sanitizeHtml(contactMessage.email),
      phone: sanitizeHtml(contactMessage.phone),
      subject: sanitizeHtml(contactMessage.subject),
      message: sanitizeHtml(contactMessage.message).replace(/\n/g, '<br />'),
    });
    return this.mailerService.send(process.env.MAIL_CONTACT, jsonConfig.subject, html);
  }
}
