import { Db } from 'mongodb';
import { StructureDocument } from '../../structures/schemas/structure.schema';
import { getDb } from '../migrations-utils/db';

export const up = async () => {
  const db: Db = await getDb();
  const cursor = db.collection('structures').find({});
  let document;
  while ((document = await cursor.next())) {
    const newDoc: StructureDocument = updateStructure(document);
    await db.collection('structures').updateOne({ _id: document._id }, [{ $set: newDoc }]);
  }
  console.log("Updated : removed 'Arrondissement' from structure's commune ");
};

export const down = async () => {
  const db: Db = await getDb();
  const cursor = db.collection('structures').find({});
  let document;
  while ((document = await cursor.next())) {
    const newDoc: StructureDocument = downgradeStructure(document);
    await db.collection('structures').updateOne({ _id: document._id }, [{ $set: newDoc }]);
  }
  console.log("Downgraded : added 'Arrondissement' to structure's commune");
};

function updateStructure(doc: StructureDocument): StructureDocument {
  if (doc?.address?.commune && doc.address.commune.startsWith('Lyon')) {
    doc.address.commune = doc.address.commune.replace('er Arrondissement', 'er');
    doc.address.commune = doc.address.commune.replace('ème Arrondissement', 'e');
  }
  return doc;
}

function downgradeStructure(doc: StructureDocument) {
  if (doc?.address?.commune && doc.address.commune.startsWith('Lyon')) {
    // First arrondissement
    if (doc.address.commune.endsWith('er')) {
      doc.address.commune = doc.address.commune + ' Arrondissement';
      return doc;
    }
    // Other arrondissement
    if (doc.address.commune.endsWith('e')) {
      doc.address.commune = doc.address.commune.slice(0, -1) + 'ème Arrondissement';
      return doc;
    }
  }
  return doc;
}
