import { Db } from 'mongodb';
import { getDb } from '../migrations-utils/db';
import { HttpService } from '@nestjs/axios';
import { lastValueFrom } from 'rxjs';

export const up = async () => {
  const db: Db = await getDb();
  const cursor = db.collection('structures').find({});
  let document;
  while ((document = await cursor.next())) {
    const newDoc = document;
    const httpService = new HttpService();
    await lastValueFrom(
      httpService.get(
        encodeURI(
          `https://download.data.grandlyon.com/geocoding/photon/api?q=${document.address.commune}&lang=fr&limit=1`
        )
      )
    ).then(async (res) => {
      newDoc.address.postcode = res.data.features[0].properties.postcode;
      await db.collection('structures').updateOne({ _id: document._id }, [{ $set: newDoc }]);
      console.log(
        `${document.structureName}, ${document.address.commune} : ${res.data.features[0].properties.postcode}`
      );
    });
  }
  console.log('Update done : postcodes added to structures');
};

export const down = async () => {
  const db: Db = await getDb();
  const cursor = db.collection('structures').find({});
  let document;
  while ((document = await cursor.next())) {
    await db.collection('structures').updateOne({ _id: document._id }, [{ $unset: 'address.postcode' }]);
  }
  console.log(`Downgrade done : postcodes removed from structures`);
};
