import { ApiProperty } from '@nestjs/swagger';
import { Type } from 'class-transformer';
import { IsArray, IsNotEmpty, IsOptional, ValidateNested } from 'class-validator';
import { PersonalOfferDocument } from '../../personal-offers/schemas/personal-offer.schema';
import { Week } from '../../shared/schemas/week.schema';
import { Address } from '../schemas/address.schema';

export class StructureDto {
  numero: string;
  createdAt: Date;
  updatedAt: Date;
  @IsOptional()
  toBeDeletedAt?: Date;

  deletedAt: Date;

  @IsNotEmpty()
  structureName: string;

  @ApiProperty({ required: true })
  @IsNotEmpty()
  structureType: string;

  description: string;

  @ValidateNested({ each: true })
  @Type(() => Address)
  address: Address;

  contactPhone?: string;
  contactMail?: string;

  website: string;
  facebook: string;
  twitter: string;
  instagram: string;
  linkedin: string;

  lockdownActivity: string;
  otherDescription: string;

  @ApiProperty({ required: true })
  @IsNotEmpty()
  pmrAccess: boolean;

  remoteAccompaniment: boolean;

  @IsNotEmpty()
  categories: any;

  freeWorkShop: string;

  @ApiProperty({ required: true })
  @IsNotEmpty()
  nbComputers: number;

  @ApiProperty({ required: true })
  @IsNotEmpty()
  nbPrinters: number;

  @ApiProperty({ required: true })
  @IsNotEmpty()
  nbScanners: number;

  exceptionalClosures: string;
  hours: Week;
  coord: number[];
  accountVerified = true; // Value is forced to true because there is no verification needed now. Cannot be removed because of old data prod
  dataShareConsentDate: Date;

  @IsArray()
  personalOffers: PersonalOfferDocument[];

  idCNFS?: string;
}
