import { ApiProperty } from '@nestjs/swagger';
import { IsArray, IsEmail, IsNotEmpty, IsOptional, IsString } from 'class-validator';
import { Types } from 'mongoose';
import { PersonalOffer } from '../../personal-offers/schemas/personal-offer.schema';

export class CreateUserDto {
  @ApiProperty({ type: String })
  @IsNotEmpty()
  @IsString()
  readonly password: string;

  @IsNotEmpty()
  @IsEmail()
  @ApiProperty({ type: String })
  email: string;

  @IsNotEmpty()
  @ApiProperty({ type: String })
  name: string;

  @IsNotEmpty()
  @ApiProperty({ type: String })
  surname: string;

  @IsNotEmpty()
  @ApiProperty({ type: String })
  phone: string;

  @IsArray()
  @IsOptional()
  structuresLink?: Array<Types.ObjectId>;

  @IsOptional()
  unattachedSince?: Date;

  @IsArray()
  @IsOptional()
  personalOffers?: PersonalOffer[];
}
