import { Test, TestingModule } from '@nestjs/testing';
import { Types } from 'mongoose';
import { ConfigurationModule } from '../../configuration/configuration.module';
import { SearchModule } from '../../search/search.module';
import { EmployerDocument } from '../schemas/employer.schema';
import { EmployerSearchService } from './employer-search.service';

const employers = [
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5ba'),
    name: 'Metro',
    validated: true,
  } as EmployerDocument,
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5bb'),
    name: 'Sopra',
    validated: true,
  } as EmployerDocument,
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5bd'),
    name: 'CAF',
    validated: true,
  } as EmployerDocument,
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5be'),
    name: 'CARSAT',
    validated: true,
  } as EmployerDocument,
  {
    _id: new Types.ObjectId('6231aefe76598527c8d0b5bf'),
    name: 'CPAM',
    validated: true,
  } as EmployerDocument,
];
describe('EmployerSearchService Search cases', () => {
  let service: EmployerSearchService;

  beforeEach(async () => {
    const module: TestingModule = await Test.createTestingModule({
      imports: [SearchModule, ConfigurationModule],
      providers: [EmployerSearchService],
    }).compile();

    service = module.get<EmployerSearchService>(EmployerSearchService);
    service['index'] = 'employer-unit-test';
    // Init test cases
    await service.dropIndex();
    await service.createEmployerIndex();
    await Promise.all(employers.map((employer) => service.indexEmployer(employer)));

    // wait for the new structures to be indexed before search
    await service.refreshIndexStructure();
    await new Promise((r) => setTimeout(r, 2000));
  }, 10000);

  it('should be defined', async () => {
    // await new Promise((r) => setTimeout(r, 9000));
    expect(service).toBeDefined();
  });

  // it('should index structures', async () => {
  //   // but we still need to wait the refresh to be done
  //   await new Promise((r) => setTimeout(r, 2000));
  // }, 10000);

  it('should find CARSAT', async () => {
    const res = await service.search('CARSAT');
    expect(res[0].name).toBe('CARSAT');
    expect(res.length).toBe(1);
  });
  it('should find CAF', async () => {
    const res = await service.search('CAF');
    expect(res[0].name).toBe('CAF');
    expect(res.length).toBe(1);
  });

  it('should index structures', async () => {
    const res = await Promise.all(employers.map((employer) => service.indexEmployer(employer)));

    expect(res).toBeTruthy();
    expect(res.length).toBe(5);
  });

  it('should update index', async () => {
    const resCaf = await service.search('CAF');
    const res = await service.update(
      resCaf[0] as EmployerDocument,
      new Types.ObjectId('6231aefe76598527c8d0b5bd').toHexString()
    );
    expect(res).toBeTruthy();
  });
  it('should delete index', async () => {
    const resCaf = await service.search('CAF');
    const res = await service.deleteIndex(
      resCaf[0] as EmployerDocument,
      new Types.ObjectId('6231aefe76598527c8d0b5bd').toHexString()
    );
    expect(res).toBeTruthy();
  });
});
